/*****************************************************************************
 * $LastChangedDate: 2011-04-23 21:07:07 -0400 (Sat, 23 Apr 2011) $
 * @file
 * @author  Jim E. Brooks  http://www.palomino3d.org
 * @brief   Module configuration.
 *//*
 * LEGAL:   COPYRIGHT (C) 2008 JIM E. BROOKS
 *          THIS SOURCE CODE IS RELEASED UNDER THE TERMS
 *          OF THE GNU GENERAL PUBLIC LICENSE VERSION 2 (GPL 2).
 *****************************************************************************/

#define PHYSICS_CONF_CC 1
#include <fstream>
#include "base/module.hh"
#include "base/conf.hh"
#include "base/conf_template_macros.hh"
#include "base/misc.hh"
#include "base/stream.hh"
using namespace base;
#include "physics/module.hh"
#include "physics/conf.hh"
#include "physics/physics_control.hh"

namespace physics {

////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////  Conf  ///////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////

namespace global { Conf gConf; }

/*****************************************************************************
 * ctor/dtor.
 *****************************************************************************/
Conf::Conf( void )
:   mValid(false),
    // cmd-line args
    // .conf file
    mMaxLandingSpeedVertical(30)  // KPH
{
}

/*****************************************************************************
 * Initialize/read configuration.
 *****************************************************************************/
void
Conf::Init( const base::InitArgs& initArgs, const string& confTxtFilename )
{
    CONF_TEMPLATE_Init_ParseCmdline_ReadConfTxt;
}

/*****************************************************************************
 * Parse cmdline args.
 *****************************************************************************/
void
Conf::ParseCmdlineArgs( int argc, char** argv )
{
    // Parse args.
    for ( int i = 1; i < argc; ++i )
    {
        if ( STREQ( argv[i], "-speed" ) )
        {
            PhysicsControl::SetSimulationSpeed( base::Argf(i+1,argc,argv) );
            CLOG << "Sim speed = " << PhysicsControl::GetSimulationSpeed() << std::endl;
            CmdargDone( i, 2 );
        }
        else if ( STREQ( argv[i], "-no-physics" ) )
        {
            // Disable physics.
            PhysicsControl::PermanentlyDisable();
            CmdargDone( i );
            CLOG << "Disabled physics." << std::endl;
        }
        else if ( STRSTR( argv[i], "-no-stall" ) )  // -no-stall[ing]
        {
            // Disable aerodynamic stalling.
            PhysicsControl::EnableStall( false );
            CmdargDone( i );
            CLOG << "Disabled stalling." << std::endl;
        }
    }
}

void
Conf::ParseCmdlineArgs2( int argc, char** argv )
{
    // NOP
}

/*****************************************************************************
 * Read from .conf file.
 *****************************************************************************/
void
Conf::ReadConfTxt( const string& confTxtFilename )
{
    CONF_TEMPLATE_ReadConfTxt;
}

void
Conf::ModuleConfTxt::ProcessField( string& field, std::ifstream& conf )
{
    bool error = false;

    if ( field == "MaxLandingSpeedVertical" )
    {
        fp f; conf >> f;
        PHYSICS_CONF.mMaxLandingSpeedVertical = SpeedKPH(f);
    }

    // Errors?
    if ( error )
    {
        CERROR << "ERROR[conf]: parameter for " << field << " is invalid." << std::endl;
        EXIT( 1 );
    }
}

/*****************************************************************************
 * Print Conf configuration.
 *****************************************************************************/
std::ostream& operator<<( std::ostream& strm, const Conf& conf )
{
    return strm;
}

} // namespace physics
